================
 ``zope.login``
================

.. image:: https://img.shields.io/pypi/v/zope.login.svg
        :target: https://pypi.python.org/pypi/zope.login/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/zope.login.svg
        :target: https://pypi.org/project/zope.login/
        :alt: Supported Python versions

.. image:: https://github.com/zopefoundation/zope.login/actions/workflows/tests.yml/badge.svg
        :target: https://github.com/zopefoundation/zope.login/actions/workflows/tests.yml

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.login/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/zope.login?branch=master

.. image:: https://readthedocs.org/projects/zopelogin/badge/?version=latest
        :target: https://zopelogin.readthedocs.io/en/latest/
        :alt: Documentation Status

This package provides login helpers for `zope.publisher
<https://zopepublisher.readethedocs.io/>`_ based on the concepts of
`zope.authentication <https://zopeauthentication.readthedocs.io>`_.
This includes support for HTTP password logins and FTP logins.

Documentation is hosted at https://zopelogin.readthedocs.io
